@@ -1,8 +1,9 @@
 from .aop import worker_threads
 from .aop import worker
-from .aop import singleton
+from .aop import cage
 from .aop import event
+from .aop import event_map
 from .master import Master
 from .params_factory import ParamsFactory
-from .param_path import ParamPath
+from .params_path import ParamsPath
 
